@@ -136,7 +136,7 @@ gpm_cell_refresh_hal_all (GpmCell *cell)
 	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
 		exists = hal_gdevice_get_uint (device, "battery.charge_level.rate",
 						  &unit->rate, NULL);
-		if (exists == FALSE && (unit->is_discharging == TRUE || unit->is_charging == TRUE)) {
+		if (exists == FALSE && (unit->is_discharging || unit->is_charging == TRUE)) {
 			gpm_warning ("could not read your battery's charge rate");
 		}
 		/* sanity check to less than 100W */
@@ -144,11 +144,21 @@ gpm_cell_refresh_hal_all (GpmCell *cell)
 			gpm_warning ("sanity checking rate from %i to 0", unit->rate);
 			unit->rate = 0;
 		}
+		/* The ACPI spec only allows this for primary cells, but in the real
+		   world we also see it for rechargeables. Sigh */
+		if (unit->rate == 0) {
+			guint raw_last_charge;
+			hal_gdevice_get_uint (device, "battery.reporting.last_full",
+					      &raw_last_charge, NULL);
+			if (raw_last_charge == 100)
+				unit->reports_percentage = TRUE;
+		}
 	}
 
 	/* sanity check that charge_level.percentage exists (if it should) */
-	exists = hal_gdevice_get_uint (device, "battery.charge_level.percentage",
-					  &unit->percentage, NULL);
+	guint percentage;
+	exists = hal_gdevice_get_uint (device, "battery.charge_level.percentage", &percentage, NULL);
+	unit->percentage = (gfloat) percentage;
 	if (exists == FALSE) {
 		gpm_warning ("could not read your battery's percentage charge.");
 	}
@@ -158,13 +168,13 @@ gpm_cell_refresh_hal_all (GpmCell *cell)
 	    unit->kind == GPM_CELL_UNIT_KIND_UPS) {
 		exists = hal_gdevice_get_uint (device,"battery.remaining_time",
 						  &unit->time_charge, NULL);
-		if (exists == FALSE && (unit->is_discharging == TRUE || unit->is_charging == TRUE)) {
+		if (exists == FALSE && (unit->is_discharging || unit->is_charging == TRUE)) {
 			gpm_warning ("could not read your battery's remaining time");
 		}
 	}
 
 	/* calculate the batteries capacity if it is primary and present */
-	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY && unit->is_present == TRUE) {
+	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY && unit->is_present) {
 		if (unit->charge_design > 0 && unit->charge_last_full > 0) {
 			if (unit->charge_design != unit->charge_last_full) {
 				float capacity;
@@ -180,7 +190,7 @@ gpm_cell_refresh_hal_all (GpmCell *cell)
 						   "%i to 0", unit->capacity);
 					unit->capacity = 0;
 				}
-				if (unit->capacity < 50) {
+				if (unit->capacity < 50 && !unit->reports_percentage) {
 					gpm_warning ("battery has a low capacity");
 					gpm_debug ("** EMIT: low-capacity");
 					g_signal_emit (cell, signals [LOW_CAPACITY], 0, unit->capacity);
@@ -199,7 +209,7 @@ gpm_cell_refresh_hal_all (GpmCell *cell)
 
 	/* this is more common than you might expect: hardware that might blow up */
 	hal_gdevice_get_bool (device, "info.is_recalled", &is_recalled, NULL);
-	if (is_recalled == TRUE) {
+	if (is_recalled) {
 		gchar *oem_vendor;
 		gchar *website;
 		hal_gdevice_get_string (device, "info.recall.vendor", &oem_vendor, NULL);
@@ -278,7 +288,7 @@ hal_device_property_modified_cb (HalGDevice   *device,
 		gpm_debug ("** EMIT: charging-changed: %i", unit->is_charging);
 		g_signal_emit (cell, signals [CHARGING_CHANGED], 0, unit->is_charging);
 		/* reset the time, as we really can't guess this without profiling */
-		if (unit->is_charging == TRUE) {
+		if (unit->is_charging) {
 			unit->time_discharge = 0;
 		}
 
@@ -287,7 +297,7 @@ hal_device_property_modified_cb (HalGDevice   *device,
 		gpm_debug ("** EMIT: discharging-changed: %i", unit->is_discharging);
 		g_signal_emit (cell, signals [DISCHARGING_CHANGED], 0, unit->is_discharging);
 		/* reset the time, as we really can't guess this without profiling */
-		if (unit->is_discharging == TRUE) {
+		if (unit->is_discharging) {
 			unit->time_charge = 0;
 		}
 
@@ -309,17 +319,19 @@ hal_device_property_modified_cb (HalGDevice   *device,
 		}
 
 	} else if (strcmp (key, "battery.charge_level.percentage") == 0) {
-		hal_gdevice_get_uint (device, key, &unit->percentage, NULL);
+		guint percent;
+		hal_gdevice_get_uint (device, key, &percent, NULL);
+		unit->percentage = (gfloat) percent;
 		gpm_debug ("** EMIT: percent-changed: %i", unit->percentage);
 		g_signal_emit (cell, signals [PERCENT_CHANGED], 0, unit->percentage);
 
 	} else if (strcmp (key, "battery.remaining_time") == 0) {
 		hal_gdevice_get_uint (device, key, &time_hal, NULL);
 		/* Gahh. We have to multiplex the time as HAL shares a key. */
-		if (unit->is_charging == TRUE) {
+		if (unit->is_charging) {
 			unit->time_charge = time_hal;
 		}
-		if (unit->is_discharging == TRUE) {
+		if (unit->is_discharging) {
 			unit->time_discharge = time_hal;
 		}
 
@@ -374,7 +386,7 @@ gpm_cell_set_hal_udi (GpmCell *cell, const gchar *udi)
 	device = cell->priv->hal_device;
 
 	ret = hal_gdevice_set_udi (device, udi);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_warning ("cannot set udi");
 		return FALSE;
 	}
@@ -391,7 +403,7 @@ gpm_cell_set_hal_udi (GpmCell *cell, const gchar *udi)
 	}
 
 	ret = gpm_cell_unit_set_kind (unit, battery_kind_str);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_warning ("battery type %s unknown", battery_kind_str);
 		g_free (battery_kind_str);
 		return FALSE;
@@ -419,7 +431,7 @@ gpm_cell_set_phone_index (GpmCell *cell, guint index)
 
 	unit->is_discharging = TRUE;
 	unit->is_present = TRUE;
-	unit->percentage = gpm_phone_get_percentage (cell->priv->phone, 0);
+	unit->percentage = (gfloat) gpm_phone_get_percentage (cell->priv->phone, 0);
 	unit->is_charging = gpm_phone_get_on_ac (cell->priv->phone, 0);
 	unit->is_discharging = !unit->is_charging;
 	return TRUE;
@@ -528,20 +540,19 @@ gpm_cell_get_description (GpmCell *cell)
 
 	details = g_string_new ("");
 	if (cell->priv->product) {
-		g_string_append_printf (details, _("<b>Product:</b> %s\n"), cell->priv->product);
+		g_string_append_printf (details, "<b>%s:</b> %s\n", _("Product"), cell->priv->product);
 	}
 	if (unit->is_present == FALSE) {
-		g_string_append (details, _("<b>Status:</b> Missing\n"));
-	} else if (gpm_cell_unit_is_charged (unit) == TRUE) {
-		g_string_append (details, _("<b>Status:</b> Charged\n"));
+		g_string_append_printf (details, "<b>%s:</b> %s\n", _("Status"), _("Missing"));
+	} else if (gpm_cell_unit_is_charged (unit)) {
+		g_string_append_printf (details, "<b>%s:</b> %s\n", _("Status"), _("Charged"));
 	} else if (unit->is_charging) {
-		g_string_append (details, _("<b>Status:</b> Charging\n"));
+		g_string_append_printf (details, "<b>%s:</b> %s\n", _("Status"), _("Charging"));
 	} else if (unit->is_discharging) {
-		g_string_append (details, _("<b>Status:</b> Discharging\n"));
+		g_string_append_printf (details, "<b>%s:</b> %s\n", _("Status"), _("Discharging"));
 	}
 	if (unit->percentage >= 0) {
-		g_string_append_printf (details, _("<b>Percentage charge:</b> %i%%\n"),
-					unit->percentage);
+		g_string_append_printf (details, "<b>%s:</b> %.1f%%\n", _("Percentage charge"), unit->percentage);
 	}
 	if (cell->priv->vendor) {
 		g_string_append_printf (details, "<b>%s</b> %s\n",
@@ -562,29 +573,29 @@ gpm_cell_get_description (GpmCell *cell)
 				     cell->priv->technology);
 			technology = cell->priv->technology;
 		}
-		g_string_append_printf (details, "<b>%s</b> %s\n",
-					_("Technology:"), technology);
+		g_string_append_printf (details, "<b>%s:</b> %s\n",
+					_("Technology"), technology);
 	}
 	if (cell->priv->serial) {
-		g_string_append_printf (details, "<b>%s</b> %s\n",
-					_("Serial number:"), cell->priv->serial);
+		g_string_append_printf (details, "<b>%s:</b> %s\n",
+					_("Serial number"), cell->priv->serial);
 	}
 	if (cell->priv->model) {
-		g_string_append_printf (details, "<b>%s</b> %s\n",
-					_("Model:"), cell->priv->model);
+		g_string_append_printf (details, "<b>%s:</b> %s\n",
+					_("Model"), cell->priv->model);
 	}
 	if (unit->time_charge > 0) {
 		gchar *time_str;
 		time_str = gpm_get_timestring (unit->time_charge);
-		g_string_append_printf (details, "<b>%s</b> %s\n",
-					_("Charge time:"), time_str);
+		g_string_append_printf (details, "<b>%s:</b> %s\n",
+					_("Charge time"), time_str);
 		g_free (time_str);
 	}
 	if (unit->time_discharge > 0) {
 		gchar *time_str;
 		time_str = gpm_get_timestring (unit->time_discharge);
-		g_string_append_printf (details, "<b>%s</b> %s\n",
-					_("Discharge time:"), time_str);
+		g_string_append_printf (details, "<b>%s:</b> %s\n",
+					_("Discharge time"), time_str);
 		g_free (time_str);
 	}
 	if (unit->capacity > 0) {
@@ -598,42 +609,42 @@ gpm_cell_get_description (GpmCell *cell)
 		} else {
 			condition = _("Poor");
 		}
-		g_string_append_printf (details, "<b>%s</b> %i%% (%s)\n",
-					_("Capacity:"),
+		g_string_append_printf (details, "<b>%s:</b> %i%% (%s)\n",
+					_("Capacity"),
 					unit->capacity, condition);
 	}
 	if (unit->measure == GPM_CELL_UNIT_MWH) {
 		if (unit->charge_current > 0) {
 			g_string_append_printf (details, "<b>%s</b> %.1f Wh\n",
-						_("Current charge:"),
+						_("Current charge"),
 						unit->charge_current / 1000.0f);
 		}
 		if (unit->charge_last_full > 0 &&
 		    unit->charge_design != unit->charge_last_full) {
-			g_string_append_printf (details, "<b>%s</b> %.1f Wh\n",
-						_("Last full charge:"),
+			g_string_append_printf (details, "<b>%s:</b> %.1f Wh\n",
+						_("Last full charge"),
 						unit->charge_last_full / 1000.0f);
 		}
 		if (unit->charge_design > 0) {
-			g_string_append_printf (details, "<b>%s</b> %.1f Wh\n",
-						_("Design charge:"),
+			g_string_append_printf (details, "<b>%s:</b> %.1f Wh\n",
+						_("Design charge"),
 						unit->charge_design / 1000.0f);
 		}
 		if (unit->rate > 0) {
-			g_string_append_printf (details, "<b>%s</b> %.1f W\n",
-						_("Charge rate:"),
+			g_string_append_printf (details, "<b>%s:</b> %.1f W\n",
+						_("Charge rate"),
 						unit->rate / 1000.0f);
 		}
 	}
 	if (unit->measure == GPM_CELL_UNIT_CSR) {
 		if (unit->charge_current > 0) {
-			g_string_append_printf (details, "<b>%s</b> %i/7\n",
-						_("Current charge:"),
+			g_string_append_printf (details, "<b>%s:</b> %i/7\n",
+						_("Current charge"),
 						unit->charge_current);
 		}
 		if (unit->charge_design > 0) {
-			g_string_append_printf (details, "<b>%s</b> %i/7\n",
-						_("Design charge:"),
+			g_string_append_printf (details, "<b>%s:</b> %i/7\n",
+						_("Design charge"),
 						unit->charge_design);
 		}
 	}
@@ -676,9 +687,9 @@ phone_device_refresh_cb (GpmPhone     *phone,
 	}
 
 	if (percentage != unit->percentage) {
-		unit->percentage = percentage;
-		gpm_debug ("** EMIT: percent-changed: %i", percentage);
-		g_signal_emit (cell, signals [PERCENT_CHANGED], 0, percentage);
+		unit->percentage = (gfloat) percentage;
+		gpm_debug ("** EMIT: percent-changed: %.1f", unit->percentage);
+		g_signal_emit (cell, signals [PERCENT_CHANGED], 0, unit->percentage);
 	}
 }
 
@@ -700,8 +711,8 @@ gpm_cell_class_init (GpmCellClass *klass)
 			      G_STRUCT_OFFSET (GpmCellClass, percent_changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__UINT,
-			      G_TYPE_NONE, 1, G_TYPE_UINT);
+			      g_cclosure_marshal_VOID__FLOAT,
+			      G_TYPE_NONE, 1, G_TYPE_FLOAT);
 	signals [DISCHARGING_CHANGED] =
 		g_signal_new ("discharging-changed",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -829,7 +840,7 @@ gpm_cell_get_battery (void)
 
 	manager = hal_gmanager_new ();
 	ret = hal_gmanager_find_capability (manager, "battery", &value, NULL);
-	if (ret == TRUE && value != NULL && value[0] != NULL) {
+	if (ret && value != NULL && value[0] != NULL) {
 		udi = g_strdup (value[0]);
 	}
 	hal_gmanager_free_capability (value);
@@ -892,7 +903,7 @@ gpm_st_cell (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "can we assign device");
 	ret = gpm_cell_set_hal_udi (cell, udi);
-	if (ret == TRUE) {
+	if (ret) {
 		gpm_st_success (test, "set type okay");
 	} else {
 		gpm_st_failed (test, "could not set type");
