@@ -37,8 +37,6 @@ typedef enum {
 	GPM_SOUND_AC_UNPLUGGED,
 	GPM_SOUND_POWER_LOW,
 	GPM_SOUND_SUSPEND_FAILURE,
-	GPM_SOUND_LID_UP,
-	GPM_SOUND_LID_DOWN,
 	GPM_SOUND_LAST
 } GpmSoundAction;
 
